"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var deepmerge = require("deepmerge");
var fs = require("fs-extra");
var path = require("path");
/**
 * Config file path.
 */
exports.configFile = path.join(process.cwd(), 'jsTestify.json');
/*
 * Get safe file path
 */
function safeFile(file) {
    return file.replace(/\//g, '_');
}
exports.safeFile = safeFile;
exports.configDefaults = {
    projectName: 'default',
    testUrl: 'localhost:4010',
    rootTestPath: 'tests',
    puppeteerOpts: {},
    suites: [],
    tests: [],
    userProfiles: []
};
/**
 * Get and parse config file.
 */
function getConfig() {
    var config;
    config = exports.configDefaults;
    try {
        config = fs.readJsonSync(exports.configFile);
    }
    catch (error) {
        console.error('Could not find or parse config file. You can use the `init` command to create one!');
        process.exit();
    }
    return deepmerge(exports.configDefaults, config);
}
exports.getConfig = getConfig;
/**
 * Write config file with provided object contents.
 *
 * @param file Configuration file to write to.
 * @param config Object to save for config file.
 */
function setConfig(file, config) {
    var content = JSON.stringify(config, null, 2);
    // save file
    fs.outputFile(file, content, function (error) {
        if (error) {
            return console.error(error);
        }
        console.log('Config file created!');
    });
}
exports.setConfig = setConfig;
//# sourceMappingURL=utility.js.map